<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineFreehand</name>
    <message>
        <location filename="../LineFreehand.js" line="+55"/>
        <source>Press to start drawing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę nacisnąć lewy przycisk myszy, aby rozpocząć rysowanie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Release to stop drawing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę zwolnić przycisk myszy, aby przestać rysować</translation>
    </message>
    <message>
        <location filename="../LineFreehandInit.js" line="+2"/>
        <source>&amp;Freehand Line</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Odręczna linia</translatorcomment>
        <translation>Linia &amp;odręczna</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw freehand line</source>
        <translatorcomment>--google--
Rysuj linie odręczne</translatorcomment>
        <translation>Rysuje linię odręczną</translation>
    </message>
</context>
</TS>
